/**
 * Copyright (c) 2014-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.clientserverapi.topology.exception;

import org.ow2.petals.clientserverapi.topology.RemoteContainer;

/**
 * An error occurs attaching a container to a domain.
 * 
 * @author Christophe DENEUX - Linagora
 */
public class AttachContainerException extends TopologyServiceException {

    private static final long serialVersionUID = 1771724545178817580L;

    private static final String MESSAGE_TEMPLATE_WITHOUT_CURRENT_CONTAINER = "Can't attach the current container to the domain '%s' using the container '%s:%s': %s";

    private static final String MESSAGE_TEMPLATE_WITH_CURRENT_CONTAINER = "Can't attach the current container '%s' to the domain '%s' using the container '%s:%s': %s";

    /**
     * @param currentContainerName
     *            The name of the current container, the one that is moving.
     * @param container
     *            The container used as entry point in the target domain to attach the current container
     * @param cause
     *            The error cause
     */
    public AttachContainerException(final String currentContainerName, final RemoteContainer container,
            final String cause) {
        super(String.format(MESSAGE_TEMPLATE_WITH_CURRENT_CONTAINER, currentContainerName,
                container.getDomainName(), container.getHost(), container.getPort(), cause));
    }

    /**
     * @param container
     *            The container used as entry point in the target domain to attach the current container
     * @param cause
     *            The error cause
     */
    public AttachContainerException(final RemoteContainer container, final Throwable cause) {
        super(String.format(MESSAGE_TEMPLATE_WITHOUT_CURRENT_CONTAINER, container.getDomainName(), container.getHost(),
                container.getPort(), cause.getMessage()), cause);
    }

    /**
     * @param currentContainerName
     *            The name of the current container, the one that is moving.
     * @param container
     *            The container used as entry point in the target domain to attach the current container
     * @param causeMsg
     *            The error cause message
     * @param cause
     *            The error cause stack trace
     */
    public AttachContainerException(final String currentContainerName, final RemoteContainer container,
            final String causeMsg, final Throwable cause) {
        super(String.format(MESSAGE_TEMPLATE_WITH_CURRENT_CONTAINER, currentContainerName, container.getDomainName(),
                container.getHost(), container.getPort(), causeMsg), cause);
    }
}
